Struct google_cloud_service_flows::vertex::chat::ChatOptions
source · pub struct ChatOptions<'a> {
pub model: ChatModel,
pub restart: bool,
pub context: Option<&'a str>,
pub examples: Option<Vec<(String, String)>>,
pub temperature: Option<f32>,
pub top_p: Option<f32>,
pub top_k: Option<u8>,
pub max_output_tokens: Option<u16>,
}Expand description
struct for setting the chat options.
Fields
model: ChatModelThe ID or name of the model to use for completion.
restart: boolWhen true, a new conversation will be created.
context: Option<&'a str>Context shapes how the model responds throughout the conversation
examples: Option<Vec<(String, String)>>List of structured messages to the model to learn how to respond to the conversation.
temperature: Option<f32>The temperature is used for sampling during the response generation, which occurs when topP and topK are applied.
top_p: Option<f32>Top-p changes how the model selects tokens for output.
top_k: Option<u8>Top-k changes how the model selects tokens for output.
max_output_tokens: Option<u16>Maximum number of tokens that can be generated in the response.